Phoenix PubSub adapter based on Redis.
To start it, list it in your supervision tree as:
{Phoenix.PubSub,
adapter: Phoenix.PubSub.Redis,
redis_opts: "redis://localhost:6379",
node_name: System.get_env("NODE")}Options
:name- The required name to register the PubSub processes, e.g.MyApp.PubSub.:node_name- The name of the node, used to filter out messages broadcast by the same node. Defaults tonode(). Must be unique.:redis_pool_size- The size of the Redis connection pool. Defaults to5.:compression_level- Compression level applied to serialized terms -0(none) to9(highest). Defaults to0.:redis_opts- Redix connection options - either a Redis URL string or a keyword list. SeeRedix.start_link/1for more information.
Summary
Functions
Returns a specification to start this module under a supervisor.
Functions
Returns a specification to start this module under a supervisor.
See Supervisor.